

# Changelog 

### 0.0.10

- Fixed wandb interface bug 

### 0.0.9

- Fixed bug in accuracy metric. 


### 0.0.8

- Fixed `metrics` import bug. 

### 0.0.7

- Largest change to date. New features: gradient accumulation, save weights every $n$ epochs, display batch loss, metrics, metrics interfaced with `train`. 

### 0.0.6

- Fixed bug in model weight saving. 

### 0.0.5
- Added model weights loading and saving. 

### 0.0.4 
- Several changes: added callbacks, changed verbose default to true, added `ModelInterface` pipeline to `utils`. 

### 0.0.3
- Added verbose option as well as wandb logging 

### 0.0.2
- Fixed a polymorphic bug 

### 0.0.1
- First version published. Provides basic data-loading utilities and the base experiment module. 


